@@ -1,6 +1,9 @@
+from __future__ import annotations
 from dataclasses import dataclass, field
 from enum import Enum
+from io import StringIO
 from dataclasses_json import config, dataclass_json
+import pandas as pd
 import typing as t
 from .utils import read_pvsyst_file
 
@@ -284,6 +287,7 @@ class SolarResourceTimeSeries(object):
     wdir: t.List[float]
     wspd: t.List[float]
     alb: t.Optional[t.List[float]] = opt_field()
+    snow: t.Optional[t.List[float]] = opt_field()
 
 @dataclass_json
 @dataclass
@@ -295,6 +299,44 @@ class SolarResource(object):
     data: SolarResourceTimeSeries
     monthly_albedo: t.Optional[t.List[float]] = opt_field()
 
+    @classmethod
+    def from_csv(cls, filename: str) -> SolarResource:
+        with open(filename) as f:
+            _meta = [f.readline().split(",") for _ in range(2)]
+            _data = pd.read_csv(f)
+        meta = {k: v for k, v in zip(*_meta)}
+        data = _data.rename(columns=_psm_data_map)
+        return cls(
+            latitude=float(meta["Latitude"]),
+            longitude=float(meta["Longitude"]),
+            elevation=float(meta["Elevation"]),
+            time_zone_offset=float(meta["Time Zone"]),
+            data=data.to_dict(orient="list"),
+        )
+
+
+_psm_data_map = {
+    "Year": "year",
+    "Month": "month",
+    "Day": "day",
+    "Hour": "hour",
+    "Minute": "minute",
+    "GHI": "gh",
+    "DNI": "dn",
+    "DHI": "df",
+    "POA": "poa",
+    "Temperature": "tdry",
+    # twet
+    "Dew Point": "tdew",
+    "Relative Humidity": "rhum",
+    "Pressure": "pres",
+    # Snow
+    "Surface Albedo": "alb",
+    # aod
+    "Wind Speed": "wspd",
+    "Wind Direction": "wdir",
+}
+
 
 @dataclass_json
 @dataclass
